@@ -210,6 +210,17 @@ static int _move_mirrors(struct volume_group *vg_from,
 	return 1;
 }
 
+/*
+ * Has the user given an option related to a new vg as the split destination?
+ */
+static int new_vg_option_specified(struct cmd_context *cmd)
+{
+	return(arg_count(cmd, clustered_ARG) ||
+	       arg_count(cmd, alloc_ARG) ||
+	       arg_count(cmd, maxphysicalvolumes_ARG) ||
+	       arg_count(cmd, maxlogicalvolumes_ARG));
+}
+
 int vgsplit(struct cmd_context *cmd, int argc, char **argv)
 {
 	struct vgcreate_params vp_new;
@@ -218,6 +229,7 @@ int vgsplit(struct cmd_context *cmd, int argc, char **argv)
 	struct volume_group *vg_to, *vg_from;
 	int opt;
 	int active;
+	int existing_vg;
 
 	if (argc < 3) {
 		log_error("Existing VG, new VG and physical volumes required.");
@@ -253,10 +265,16 @@ int vgsplit(struct cmd_context *cmd, int argc, char **argv)
 	if ((vg_to = vg_lock_and_read(cmd, vg_name_to, NULL,
 				      LCK_VG_WRITE | LCK_NONBLOCK,
 				      0, 0))) {
-		log_warn("Volume group \"%s\" already exists", vg_name_to);
+		existing_vg = 1;
+		if (new_vg_option_specified(cmd)) {
+			log_error("Volume group \"%s\" exists, but new VG "
+				    "option specified", vg_name_to);
+			goto error;
+		}
 		if (!vgs_are_compatible(cmd, vg_from,vg_to))
 			goto error;
 	} else {
+		existing_vg = 0;
 
 		/* Set metadata format of original VG */
 		/* FIXME: need some common logic */
@@ -269,11 +287,15 @@ int vgsplit(struct cmd_context *cmd, int argc, char **argv)
 		vp_def.alloc = vg_from->alloc;
 		vp_def.clustered = 0;
 
-		if (fill_vg_create_params(cmd, vg_name_to, &vp_new, &vp_def))
+		if (fill_vg_create_params(cmd, vg_name_to, &vp_new, &vp_def)) {
+			unlock_vg(cmd, vg_name_from);
 			return EINVALID_CMD_LINE;
+		}
 
-		if (validate_vg_create_params(cmd, &vp_new))
+		if (validate_vg_create_params(cmd, &vp_new)) {
+			unlock_vg(cmd, vg_name_from);
 			return EINVALID_CMD_LINE;
+		}
 
 		if (!(vg_to = vg_create(cmd, vg_name_to, vp_new.extent_size,
 					vp_new.max_pv, vp_new.max_lv,
@@ -339,7 +361,8 @@ int vgsplit(struct cmd_context *cmd, int argc, char **argv)
 	}
 
 	/* Remove EXPORTED flag from new VG */
-	if (!(vg_to = vg_lock_and_read(cmd, vg_name_to, NULL, LCK_NONE, 0,
+	if (!test_mode() &&
+	    !(vg_to = vg_lock_and_read(cmd, vg_name_to, NULL, LCK_NONE, 0,
 				       CORRECT_INCONSISTENT | FAIL_INCONSISTENT))) {
 		log_error("Volume group \"%s\" became inconsistent: please "
 			  "fix manually", vg_name_to);
@@ -356,7 +379,8 @@ int vgsplit(struct cmd_context *cmd, int argc, char **argv)
 	unlock_vg(cmd, vg_name_from);
 	unlock_vg(cmd, vg_name_to);
 
-	log_print("Volume group \"%s\" successfully split from \"%s\"",
+	log_print("%s volume group \"%s\" successfully split from \"%s\"",
+		  existing_vg ? "Existing" : "New",
 		  vg_to->name, vg_from->name);
 	return ECMD_PROCESSED;
 
